#
# balci-fishing.R, 18 May 24
#
# Data from:
# Dynamics of retrospective timing: A big data approach
# Fuat Balcı, Hüseyin Ünübol, Simon Grondin, Gökben Hızlı Sayar, Virginie van Wassenhove, Marc Wittmann

library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
# pal_col=rainbow(3)


bal=read.csv("Balci_est_act.csv.xz", as.is=TRUE)

# Build model based on data cleaned according to paper
PropTime=(bal$Estimation/bal$Elapsed_Duration)
# Line 22 of file 13423_2023_2277_MOESM3_ESM.m
paper=subset(bal, is.finite(PropTime) & (PropTime >= 0.1) & (PropTime <= 10) &
			(Elapsed_Duration >= 8) & (Elapsed_Duration <= 90) &
			(Estimation <= 180))

Est_Elap=glm(log(Estimation) ~ log(Elapsed_Duration), data=paper)
summary(Est_Elap)
#                       Estimate Std. Error t value Pr(>|t|)    
# (Intercept)           0.712726   0.017368   41.04   <2e-16 ***
# log(Elapsed_Duration) 0.733787   0.005335  137.53   <2e-16 ***

Elap_Est=glm(log(Elapsed_Duration) ~ log(Estimation), data=paper)
summary(Elap_Est)
#                       Estimate Std. Error t value Pr(>|t|)    
# (Intercept)     1.364143   0.013701   99.56   <2e-16 ***
# log(Estimation) 0.604549   0.004396  137.53   <2e-16 ***


# My analysis code

x_range=1:100

plot(bal$Elapsed_Duration, bal$Estimation, log="xy", col=pal_col[2],
	xlim=c(7, 100), ylim=c(5, 100),
	xlab="Elapsed (mins)", ylab="Estimated (mins)")

lines(c(1, 100), c(1, 100), col="grey")

bal1_mod=glm(Estimation ~ log(Elapsed_Duration), data=bal, family=poisson,
					subset=(Elapsed_Duration > 7) & (Elapsed_Duration < 180) &
						(Estimation > 4) & (Estimation < 180))
# summary(bal1_mod)
pred=predict(bal1_mod, newdata=data.frame(Elapsed_Duration=x_range))
lines(x_range, exp(pred), col=pal_col[1])

# bal1a_mod=glm(Estimation ~ log(Elapsed_Duration)+I(log(Elapsed_Duration)^2), data=bal, family=poisson,
# 					subset=(Elapsed_Duration > 0) & (Estimation > 7))
# summary(bal1a_mod)
# pred=predict(bal1a_mod, newdata=data.frame(Elapsed_Duration=x_range))
# lines(x_range, exp(pred), col=pal_col[1], lty=2)


bal2_mod=glm(Elapsed_Duration ~ log(Estimation), data=bal, family=poisson,
					subset=(Elapsed_Duration > 7) & (Elapsed_Duration < 180) &
						(Estimation > 4) & (Estimation < 180))
# summary(bal2_mod)
pred=predict(bal2_mod, newdata=data.frame(Estimation=x_range))
lines(exp(pred), x_range, col=pal_col[3])


# bal2a_mod=glm(Elapsed_Duration ~ log(Estimation)+I(log(Estimation)^2), data=bal, family=poisson,
# 					subset=(Elapsed_Duration > 0) & (Estimation > 7))
# summary(bal2a_mod)
# pred=predict(bal2a_mod, newdata=data.frame(Estimation=x_range))
# lines(exp(pred), x_range, col=pal_col[3], lty=2)


est_cnt=count(bal$Estimation)
act_cnt=count(bal$Elapsed_Duration)
plot(est_cnt, log="y",
	xlim=c(1, 180),
	xlab="Minutes", ylab="Estimates")

plot(act_cnt, log="y",
	xlim=c(1, 180),
	xlab="Minutes", ylab="Actuals")

est_top=est_cnt[order(est_cnt$freq, decreasing=TRUE), ]
act_top=act_cnt[order(act_cnt$freq, decreasing=TRUE), ]

head(est_top, n=10)
#     x freq
# 28 20 4482
# 21 15 3675
# 41 30 3033
# 35 25 2409
# 15 10 1879
# 53 40 1005
# 46 35  938
# 60 45  671
# 26 18  512
# 25 17  456

head(act_top, n=10)
#     x freq
# 27 20 2073
# 37 30 1861
# 32 25 1534
# 21 15 1293
# 42 35  868
# 30 23  828
# 29 22  810
# 24 18  768
# 48 40  753
# 23 17  728


# Fit an error-in-variables model

library("demming")

est_dem=deming(log(Estimation) ~ log(Elapsed_Duration), data=paper)
print(est_dem)

act_dem=deming(log(Elapsed_Duration) ~ log(Estimation), data=paper)
print(act_dem)

# Attempts to generate data that duplicates the model fitting behavior

x=10*rpois(1000, 3)
# y=1.2+30*runif(1000, -1, 1)+ 0.8*x
y=17*rpois(1000, 1)+ 0.7*x
cov(x, y)
# [1] 217.4444
glm(x ~ y)
# (Intercept)            y  
#      11.834        0.463 
glm(y ~ x)
# (Intercept)            x  
#     19.4641       0.6398

cov(x, y)/sd(y)^2
# [1] 0.4630107
cov(x, y)/sd(x)^2
# [1] 0.6397663

x=runif(1000, 5, 100)
y=1.2+50*runif(1000, -1, 1)+ 0.8*x
cov(x, y)
# [1] 616.9935

cov(x, y)/sd(y)^2
# [1] 0.4652133
cov(x, y)/sd(x)^2
# [1] 0.8070938

glm(x ~ y)
# (Intercept)            y  
#     32.2117       0.4652 
glm(y~x)
# (Intercept)            x  
#      2.2449       0.8071

